@@ -4,9 +4,10 @@ class CustomPagination(PageNumberPagination):
     page_query_param = 'p'
     page_size_query_param = 'page_size'
 
-    def __init__(self, page_size=None, max_page_size=None):
+    def __init__(self, page_size=6, max_page_size=100):
         self.page_size = page_size
         self.max_page_size = max_page_size
+        self.count = None
 
     def paginate_data(self, data, request):
         self.page = request.query_params.get(self.page_query_param, 1)
